@@ -1,3 +1,7 @@
+.onAttach <- function(libname, pkgname) {
+  packageStartupMessage("Visit <https://db.nomics.world>.")
+}
+
 .onLoad <- function(libname, pkgname) {
   # To ensure backward compatibility
   pkg <- getNamespace(pkgname)
@@ -16,21 +20,28 @@
   )
 
   # Package options
-  op <- options()
-  op.rdbnomics <- list(
-    rdbnomics.mask_compatible_providers = c(
-      "BIS", "ECB", "Eurostat", "FED", "ILO", "IMF", "INSEE", "OECD", "WTO"
-    ),
+  opts <- list(
     rdbnomics.use_readLines = FALSE,
-    rdbnomics.sleep_run = 2L,
+    rdbnomics.sleep_run = 1L,
     rdbnomics.try_run = 2L,
     rdbnomics.verbose_warning = TRUE,
     rdbnomics.api_base_url = "https://api.db.nomics.world",
     rdbnomics.api_version = 22,
     rdbnomics.authorized_api_version = c(21, 22),
     rdbnomics.verbose_warning_readLines = FALSE,
-    rdbnomics.timestamp_tz = "GMT"
+    rdbnomics.timestamp_tz = "GMT",
+    rdbnomics.http_ok = "200[[:blank:]]+OK$",
+    rdbnomics.curl_config = NULL,
+    rdbnomics.rdb_no_arg = TRUE
   )
+  opts <- append(
+    opts,
+    list(rdbnomics = sort(gsub("rdbnomics\\.", "", names(opts)))),
+    0
+  )
+
+  op <- options()
+  op.rdbnomics <- opts
   toset <- !(names(op.rdbnomics) %in% names(op))
   if(any(toset)) options(op.rdbnomics[toset])
   invisible()
